<?php

/**
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

/*
 * Authors:
 * - sr_YU, sr_CS locale Danilo Segan bug-glibc-locales@gnu.org
 */
return require __DIR__.'/sr_Cyrl.php';
